ConversionOptionsBuilder

Struct ConversionOptionsBuilder 

pub struct ConversionOptionsBuilder(/* private fields */);
Builder for ConversionOptions.

All fields start with default values. Call .build() to produce the final options.

Implementations

Source

impl ConversionOptionsBuilder

pub const fn output_format(self, value: OutputFormat) -> Self

Set the value.

pub const fn include_document_structure(self, value: bool) -> Self

Set the value.

pub const fn extract_metadata(self, value: bool) -> Self

Set the value.

pub const fn extract_images(self, value: bool) -> Self

Set the value.

pub const fn heading_style(self, value: HeadingStyle) -> Self

Set the value.

pub const fn list_indent_type(self, value: ListIndentType) -> Self

Set the value.

pub const fn list_indent_width(self, value: usize) -> Self

Set the value.

pub fn bullets(self, value: impl Into<String>) -> Self

Set the value.

pub const fn strong_em_symbol(self, value: char) -> Self

Set the value.

pub const fn code_block_style(self, value: CodeBlockStyle) -> Self

Set the value.

pub const fn newline_style(self, value: NewlineStyle) -> Self

Set the value.

pub const fn highlight_style(self, value: HighlightStyle) -> Self

Set the value.

pub fn code_language(self, value: impl Into<String>) -> Self

Set the value.

Set the value.

Set the value.

pub const fn default_title(self, value: bool) -> Self

Set the value.

pub const fn br_in_tables(self, value: bool) -> Self

Set the value.

pub const fn compact_tables(self, value: bool) -> Self

Set the value.

pub fn sub_symbol(self, value: impl Into<String>) -> Self

Set the value.

pub fn sup_symbol(self, value: impl Into<String>) -> Self

Set the value.

pub const fn escape_asterisks(self, value: bool) -> Self

Set the value.

pub const fn escape_underscores(self, value: bool) -> Self

Set the value.

pub const fn escape_misc(self, value: bool) -> Self

Set the value.

pub const fn escape_ascii(self, value: bool) -> Self

Set the value.

pub const fn whitespace_mode(self, value: WhitespaceMode) -> Self

Set the value.

pub const fn strip_newlines(self, value: bool) -> Self

Set the value.

pub const fn wrap(self, value: bool) -> Self

Set the value.

pub const fn wrap_width(self, value: usize) -> Self

Set the value.

pub const fn convert_as_inline(self, value: bool) -> Self

Set the value.

pub const fn skip_images(self, value: bool) -> Self

Set the value.

pub const fn url_escape_style(self, value: UrlEscapeStyle) -> Self

Set the value.

pub fn strip_tags(self, tags: Vec<String>) -> Self

Set the list of HTML tag names whose content is stripped from output.

pub fn preserve_tags(self, tags: Vec<String>) -> Self

Set the list of HTML tag names that are preserved verbatim in output.

pub fn keep_inline_images_in(self, tags: Vec<String>) -> Self

Set the list of HTML tag names whose <img> children are kept inline.

pub const fn max_image_size(self, value: u64) -> Self

Set the value.

pub const fn capture_svg(self, value: bool) -> Self

Set the value.

pub const fn infer_dimensions(self, value: bool) -> Self

Set the value.

pub const fn max_depth(self, value: Option<usize>) -> Self

Set the value.

pub fn exclude_selectors(self, selectors: Vec<String>) -> Self

Set the list of CSS selectors for elements to exclude entirely from output.

pub const fn preprocessing(self, preprocessing: PreprocessingOptions) -> Self

Set the pre-processing options applied to the HTML before conversion.

pub fn encoding(self, value: impl Into<String>) -> Self

Set the value.

pub const fn debug(self, value: bool) -> Self

Set the value.

pub const fn tier_strategy(self, value: TierStrategy) -> Self

Set the value.

pub fn build(self) -> ConversionOptions

Build the final ConversionOptions.